﻿using System.Collections.Generic;
using System.Net.Http;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using UsingHttpClientFactoryInsideProgram.Model;

namespace UsingHttpClientFactoryInsideProgram.Controllers
{
    [Produces("application/json")]
    [Route("api/[controller]")]
    public class BreweryController : Controller
    {
        private readonly IHttpClientFactory _httpClientFactory;

        public BreweryController(IHttpClientFactory httpClientFactory)
        {
            _httpClientFactory = httpClientFactory;
        }

        public async Task<IActionResult> Get(string state = "Massachusetts", string name = "night shift brewing")
        {
            string requestEndpoint = $"?by_state={state}&by_name={name}";        

            var httpClient = _httpClientFactory.CreateClient("OpenBreweryDb");

            var response = await httpClient.GetAsync(requestEndpoint);
            if (response.IsSuccessStatusCode)
            {
                var breweries = response.Content.ReadAsAsync<List<Brewery>>().Result;
                return Ok(breweries);
            }

            return StatusCode((int)response.StatusCode, response.Content.ReadAsStringAsync());
        }
    }
}
